@@ -51,12 +51,52 @@ cohens_f <- function(x, ...) {
 }
 
 
-#' @importFrom effectsize standardize_parameters
+
+
+
+
+#' @importFrom effectsize eta_squared
 #' @rdname r2
 #' @export
-std_beta <- function(x, ...) {
-  .Deprecated("effectsize::standardize_parameters()")
-  effectsize::standardize_parameters(x, ...)
+eta_sq <- function(x, ...) {
+  .Deprecated("effectsize::eta_squared()")
+  effectsize::eta_squared(x)
+}
+
+
+#' @importFrom effectsize epsilon_squared
+#' @rdname r2
+#' @export
+epsilon_sq <- function(x, ...) {
+  .Deprecated("effectsize::epsilon_squared()")
+  effectsize::epsilon_squared(x)
+}
+
+
+#' @importFrom effectsize omega_squared
+#' @rdname r2
+#' @export
+omega_sq <- function(x, ...) {
+  .Deprecated("effectsize::omega_sqared()")
+  effectsize::omega_squared(x)
+}
+
+
+#' @importFrom parameters rescale_weights
+#' @rdname r2
+#' @export
+scale_weights <- function(x, ...) {
+  .Deprecated("parameters::rescale_weights()")
+  parameters::rescale_weights(x, ...)
+}
+
+
+#' @importFrom parameters model_parameters
+#' @rdname r2
+#' @export
+tidy_stan <- function(x, ...) {
+  .Deprecated("parameters::model_parameters()")
+  parameters::model_parameters(x, ...)
 }
 
 
@@ -67,3 +107,14 @@ robust <- function(x, ...) {
   .Deprecated("parameters::standard_error_robust()")
   parameters::standard_error_robust(x, ...)
 }
+
+
+#' @importFrom bayestestR mediation
+#' @rdname r2
+#' @export
+mediation <- function(x, ...) {
+  .Deprecated("bayestestR::mediation()")
+  bayestestR::mediation(x, ...)
+}
+
+
